pub struct ProviderConfig {
pub profile: ProviderProfile,
pub runner: Symbol,
pub codec: Symbol,
pub endpoint: String,
pub model: String,
pub api_key_env: Option<String>,
pub locality: Symbol,
pub timeout: Duration,
pub stream: bool,
pub tools: bool,
pub max_output_bytes: usize,
}Expand description
Concrete HTTP runner configuration derived from a provider profile and an option map.
Fields
profile: ProviderProfileSource provider profile.
runner: SymbolRunner symbol after applying a name override.
codec: SymbolCodec symbol after applying a codec override.
endpoint: StringBase endpoint used by the HTTP runner.
model: StringModel name to send to the provider codec.
api_key_env: Option<String>Environment variable carrying the provider secret, when any.
locality: SymbolRunner locality after endpoint posture has been classified.
timeout: DurationHTTP timeout.
stream: boolWhether requests should use streaming.
tools: boolWhether request encoding should include tools.
max_output_bytes: usizeMaximum decoded provider response size.
Implementations
Sourceimpl ProviderConfig
impl ProviderConfig
Sourcepub fn from_options(
profile: ProviderProfile,
cx: &mut Cx,
options: &HashMap<String, Value>,
) -> Result<Self>
pub fn from_options( profile: ProviderProfile, cx: &mut Cx, options: &HashMap<String, Value>, ) -> Result<Self>
Builds provider config from the same option map used by the existing agent runner constructors.